
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-07-19T14:54:26-0700",
 "dirty": false,
 "error": null,
 "full-revisionid": "a28ba8ca98aee258a6bd9d517c927e0f89ce78a9",
 "version": "0.1.0-alpha.2"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
